@@ -30,65 +30,54 @@
 #include "main-win.h"
 
 static char** files = NULL;
+static gboolean should_display_version = FALSE;
 
 static GOptionEntry opt_entries[] =
 {
     {G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &files, NULL, N_("[FILE]")},
+    {"version", 'v', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &should_display_version,
+                 N_("Print version information and exit"), NULL },
     { NULL }
 };
 
 #define PIXMAP_DIR        PACKAGE_DATA_DIR "/gpicview/pixmaps/"
 
-void register_icons()
-{
-    GtkIconFactory* factory = gtk_icon_factory_new();
-    GdkPixbuf* pix;
-    GtkIconSet* set = NULL;
-
-#ifndef GTK_STOCK_FULLSCREEN    // before gtk+ 2.8
-#define GTK_STOCK_FULLSCREEN    "gtk-fullscreen"
-    pix = gdk_pixbuf_new_from_file( PIXMAP_DIR "fullscreen.png", NULL);
-    set = gtk_icon_set_new_from_pixbuf(pix);
-    g_object_unref( pix );
-    gtk_icon_factory_add( factory, GTK_STOCK_FULLSCREEN, set );
-#endif
-    pix = gdk_pixbuf_new_from_file( PIXMAP_DIR"clockwise.png", NULL);
-    set = gtk_icon_set_new_from_pixbuf(pix);
-    g_object_unref( pix );
-    gtk_icon_factory_add( factory, "gtk-clockwise", set );
-
-    pix = gdk_pixbuf_new_from_file( PIXMAP_DIR"counterclockwise.png", NULL);
-    set = gtk_icon_set_new_from_pixbuf(pix);
-    g_object_unref( pix );
-    gtk_icon_factory_add( factory, "gtk-counterclockwise", set );
-
-    gtk_icon_factory_add_default( factory );
-}
-
 int main(int argc, char *argv[])
 {
     GError *error = NULL;
     GOptionContext *context;
     MainWin* win;
 
-    context = g_option_context_new ("- simple image viewer");
-    g_option_context_add_main_entries (context, opt_entries, GETTEXT_PACKAGE);
-    g_option_context_add_group (context, gtk_get_option_group (TRUE));
-    g_option_context_parse (context, &argc, &argv, &error);
-//    gtk_init( &argc, &argv );    // this is not needed if g_option_context_parse is called
-
 #ifdef ENABLE_NLS
     bindtextdomain ( GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR );
     bind_textdomain_codeset ( GETTEXT_PACKAGE, "UTF-8" );
     textdomain ( GETTEXT_PACKAGE );
 #endif
 
-    register_icons();
+    context = g_option_context_new ("- simple image viewer");
+    g_option_context_add_main_entries (context, opt_entries, GETTEXT_PACKAGE);
+    g_option_context_add_group (context, gtk_get_option_group (TRUE));
+    if ( !g_option_context_parse (context, &argc, &argv, &error) )
+    {
+        g_print( "option parsing failed: %s\n", error->message);
+        return 1;
+    }
+
+    if( should_display_version )
+    {
+        printf( "gpicview %s\n", VERSION );
+        return 0;
+    }
+
+    gtk_icon_theme_append_search_path(gtk_icon_theme_get_default(), PIXMAP_DIR);
 
     load_preferences();
 
     win = (MainWin*)main_win_new();
 
+    if ( pref.open_maximized )
+        gtk_window_maximize( (GtkWindow*)win );
+
     // FIXME: need to process multiple files...
     if( files )
     {
